@@ -1,3 +1,4 @@
+import StringIO
 from kernel import kernel
 import pycurl
 import random
@@ -6,11 +7,16 @@ __author__ = 'negash'
 
 
 def curl(url, tor=False):
+    b = StringIO.StringIO()
     a = pycurl.Curl()
+    a.setopt(pycurl.WRITEFUNCTION, b.write)
     a.setopt(pycurl.URL, url)
     a.setopt(pycurl.USERAGENT, random.choice(kernel['user_agent']))
     if tor:
         a.setopt(pycurl.PROXY, 'localhost')
         a.setopt(pycurl.PROXYPORT, 9050)
     a.setopt(pycurl.PROXYTYPE, pycurl.PROXYTYPE_SOCKS5)
-    return a.perform()
\ No newline at end of file
+    a.perform()
+    a.close()
+    html = b.getvalue()
+    return html
\ No newline at end of file
